variable "function_name" {
  description = "A unique name for your Lambda Function."
  type        = string
}

variable "filename" {
  description = "Path to lambda zip."
  type        = string
}

variable "package_type" {
  description = "The Lambda deployment package type."
  type        = string
}

variable "handler" {
  description = "The function entrypoint in your code."
  type        = string
}

variable "runtime" {
  description = "Runtime to use for code execution."
  type        = string
}

variable "memory_size" {
  description = "Amount of memory in MB your Lambda Function can use at runtime."
  type        = number
}

variable "description" {
  description = "Description of what your Lambda Function does."
  type        = string
}

variable "environment" {
  description = "DB Environment variables configuration for the Lambda function."
  type        = map(string)
  default     = { DEPLOYMENT_MODEL = "mcs2" }
}

variable "extra_environment" {
  description = "Extra environment variables configuration for the Lambda function."
  type        = map(string)
  default     = { DEPLOYMENT_MODEL = "mcs2" }
}

variable "default_env_vars" {
  description = "A mapping of variables that are added by default to lambda environment variables"
  type        = map(string)
  default     = {}
}

variable "infra_mount" {
  description = "Infra mount values from kubernetes."
  type        = map(string)
  default     = {}
}

variable "tags" {
  description = "A mapping of tags to assign to the Lambda function."
  type        = map(string)
}

variable "timeout" {
  description = "The amount of time your Lambda Function has to run in seconds."
  type        = number
}

variable "subnet_ids" {
  default = []
  type    = list(string)
}

variable "security_group_ids" {
  default = []
  type    = list(string)
}

variable "cloudwatch_retention" {
  description = "Retention log policy."
  type        = number
}

variable "publish" {
  description = "Whether to publish creation/change as new Lambda Function Version."
  type        = string
}

variable "reserved_concurrent_executions" {
  description = "Amount of reserved concurrent executions for this lambda function."
  type        = number
}

variable "dlq_target_arn" {
  description = "ARN of the Lambda DLQ Resource."
  type        = string
  default     = ""
}

variable "lambda_role_arn" {
  description = "ARN of the Lambda Function Role."
  type        = string
}

variable "layers" {
  type    = list(string)
  default = []
}

variable "iam_policy_prefix" {
  type = string
}

# ---------------------------------------------------------------------------------------------------------------------
# Event PARAMETERS
# ---------------------------------------------------------------------------------------------------------------------

variable "sqs_enable" {
  description = "Conditionally enables this module."
  type        = bool
  default     = false
}

variable "dynamodb_enable" {
  description = "Conditionally enables this module."
  type        = bool
  default     = false
}

variable "kinesis_enable" {
  description = "Conditionally enables this module."
  type        = bool
  default     = false
}

variable "event_source_arn" {
  description = "Event source ARN."
  type        = string
  default     = ""
}

variable "batch_size" {
  description = "The largest number of records that Lambda will retrieve from your event source at the time of invocation. Defaults to 10 for SQS."
}

variable "event_source_mapping_enabled" {
  description = "Determines if the mapping will be enabled on creation."
}

variable "starting_position" {
  description = "The position in the stream where AWS Lambda should start reading. Must be one of either TRIM_HORIZON or LATEST."
}

# Variables for Async Invocation Configuration
variable "max_event_age" {
  description = "Maximum Age of Event. Defaults to 6 hours"
  type = number
  default = 21600
}

variable "max_retry" {
  description = "Maximum Retry Attempts that ranges between 0-2. Defaults to 2"
  type = number
  default = 2
}

variable "asyncInv_enable" {
  type    = bool
  default = false
}

variable "resource_based_policies_lambda_aws_service" {
  type    = list(map(string))
  default = []
}

variable "enable_iam_policies" {
  type    = bool
  default = true
}